@@ -30,7 +30,7 @@ def test_get_wiki():
 
     assert response['status'] == '200'
     assert response['content-type'] == 'text/html; charset=UTF-8'
-    assert '\n<title>\nTiddlyWeb Loading\n</title>\n' in content
+    assert '\n<title> TiddlyWeb Loading </title>\n' in content
     assert 'i am tiddler 8' in content
 
 
@@ -46,7 +46,7 @@ def test_get_wiki_with_title():
             method='GET')
 
     assert response['status'] == '200'
-    assert '\n<title>\nWow //cow// moo\n</title>\n' in content
+    assert '\n<title> Wow //cow// moo </title>\n' in content
 
     tiddler = Tiddler('SiteSubtitle')
     tiddler.bag = u'bag1'
@@ -58,7 +58,7 @@ def test_get_wiki_with_title():
             method='GET')
 
     assert response['status'] == '200'
-    assert '<title>\nWow //cow// moo - MooCow\n</title>' in content
+    assert '<title> Wow //cow// moo - MooCow </title>' in content
     assert 'MooCow' in content
 
     tiddler = Tiddler('SiteTitle')
@@ -70,7 +70,7 @@ def test_get_wiki_with_title():
             method='GET')
 
     assert response['status'] == '200'
-    assert '<title>\nMooCow\n</title>' in content
+    assert '<title> MooCow </title>' in content
     assert 'MooCow' in content
 
     tiddler = Tiddler('MarkupPreHead', 'bag1')
@@ -95,4 +95,4 @@ def test_get_wiki_with_title():
             method='GET')
     assert response['status'] == '200'
     # WindowTitle overrides the SiteTitle created up the stack
-    assert '<title>\nA window title\n</title>' in content
+    assert '<title> A window title </title>' in content
